﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Runtime.InteropServices;

namespace GcDevicePc
{
    public class IniHelper
    {
        // 声明INI文件的写操作函数 WritePrivateProfileString()
        [System.Runtime.InteropServices.DllImport("kernel32", EntryPoint = "WritePrivateProfileStringW", CharSet = CharSet.Unicode)]
        private static extern long WritePrivateProfileStringW(string section, string key, string val, string filePath);

        // 声明INI文件的读操作函数 GetPrivateProfileString()
        [System.Runtime.InteropServices.DllImport("kernel32",EntryPoint = "GetPrivateProfileStringW", CharSet = CharSet.Unicode)]
        private static extern int GetPrivateProfileStringW(string section, string key, string def, System.Text.StringBuilder retVal, int size, string filePath);
   
        private string sPath = null;
        public IniHelper(string path)
        {
            this.sPath = path;
        }

        public void IniHelperRename(string path)
        {
            this.sPath = path;
        }

        public void WriteValue(string section, string key, string value)
        {
            // section=配置节，key=键名，value=键值，path=路径
            WritePrivateProfileStringW(section, key, value, sPath);
        }

        public string ReadValue(string section, string key)
        {
            // 每次从ini中读取多少字节
            System.Text.StringBuilder temp = new System.Text.StringBuilder(255);
            // section=配置节，key=键名，temp=上面，path=路径
            GetPrivateProfileStringW(section, key, "", temp, 255, sPath);
            return temp.ToString();
        }
    
        public void WriteProfileBool(string section, string key, bool val)
        {
            if (val == false)
                WritePrivateProfileStringW(section, key, "0", sPath);
            else
                WritePrivateProfileStringW(section, key, "1", sPath);
        }

        public void WriteProfileInt(string section, string key, int val)
        {
            WritePrivateProfileStringW(section, key, val.ToString(), sPath);
        }

        public void EraseSection(string sectionName)
        {
            WritePrivateProfileStringW(sectionName, null, null, sPath);
        }


        public void WriteProfileFloat(string section, string key, float val)
        {
            WritePrivateProfileStringW(section, key, val.ToString(), sPath);
        }

        public void WriteProfileString(string section, string key, string val)
        {
            WriteValue(section,key,val);
        }

        public ushort GetProfileInt(string section, string key, int Default)
        {
            string val;
            
            val = ReadValue(section, key);
            if (val == "" || val == "-1")
                val = Default.ToString();

            return (ushort)Convert.ToInt32(val);
        }

        public float GetProfileFloat(string section, string key, float Default)
        {
            string val;

            val = Default.ToString();
            val = ReadValue(section, key);
            if (val == "" || val == "-1")
                val = Default.ToString();

            return float.Parse(val);
        }

        public string GetProfileString(string section, string key)
        {
            string val;

            val = ReadValue(section, key);

            return val;
        }
    }
}
